@@ -20,12 +20,13 @@ import logging
 import os
 import re
 from datetime import datetime
-from typing import Union, List
+from typing import Union, List, Optional
 
 import pyrogram
 from pyrogram import raw
 from pyrogram import types
 from pyrogram import utils
+from pyrogram import enums
 from pyrogram.file_id import FileType
 
 log = logging.getLogger(__name__)
@@ -43,10 +44,15 @@ class SendMediaGroup:
             "types.InputMediaDocument"
         ]],
         disable_notification: bool = None,
-        reply_to_message_id: int = None,
         message_thread_id: int = None,
+        reply_to_message_id: int = None,
+        reply_to_story_id: int = None,
+        quote_text: str = None,
+        parse_mode: Optional["enums.ParseMode"] = None,
+        quote_entities: List["types.MessageEntity"] = None,
         schedule_date: datetime = None,
         protect_content: bool = None,
+        invert_media: bool = None,
     ) -> List["types.Message"]:
         """Send a group of photos or videos as an album.
 
@@ -65,11 +71,25 @@ class SendMediaGroup:
                 Sends the message silently.
                 Users will receive a notification with no sound.
 
+            message_thread_id (``int``, *optional*):
+                Unique identifier for the target message thread (topic) of the forum.
+                for forum supergroups only.
+
             reply_to_message_id (``int``, *optional*):
                 If the message is a reply, ID of the original message.
 
-            message_thread_id (``int``, *optional*):
-                If the message is in a thread, ID of the original message.
+            reply_to_story_id (``int``, *optional*):
+                Unique identifier for the target story.
+
+            quote_text (``str``):
+                Text of the quote to be sent.
+
+            parse_mode (:obj:`~pyrogram.enums.ParseMode`, *optional*):
+                By default, texts are parsed using both Markdown and HTML styles.
+                You can combine both syntaxes together.
+
+            quote_entities (List of :obj:`~pyrogram.types.MessageEntity`):
+                List of special entities that appear in quote text, which can be specified instead of *parse_mode*.
 
             schedule_date (:py:obj:`~datetime.datetime`, *optional*):
                 Date when the message will be automatically sent.
@@ -77,6 +97,9 @@ class SendMediaGroup:
             protect_content (``bool``, *optional*):
                 Protects the contents of the sent message from forwarding and saving.
 
+            invert_media (``bool``, *optional*):
+                Invert media.
+
         Returns:
             List of :obj:`~pyrogram.types.Message`: On success, a list of the sent messages is returned.
 
@@ -394,16 +417,25 @@ class SendMediaGroup:
                 )
             )
 
-        reply_to = utils.get_reply_head_fm(message_thread_id, reply_to_message_id)
+        quote_text, quote_entities = (await utils.parse_text_entities(self, quote_text, parse_mode, quote_entities)).values()
 
+        peer = await self.resolve_peer(chat_id)
         r = await self.invoke(
             raw.functions.messages.SendMultiMedia(
-                peer=await self.resolve_peer(chat_id),
+                peer=peer,
                 multi_media=multi_media,
                 silent=disable_notification or None,
-                reply_to=reply_to,
+                reply_to=utils.get_reply_to(
+                    reply_to_message_id=reply_to_message_id,
+                    message_thread_id=message_thread_id,
+                    reply_to_peer=peer,
+                    reply_to_story_id=reply_to_story_id,
+                    quote_text=quote_text,
+                    quote_entities=quote_entities,
+                ),
                 schedule_date=utils.datetime_to_timestamp(schedule_date),
-                noforwards=protect_content
+                noforwards=protect_content,
+                invert_media=invert_media
             ),
             sleep_threshold=60
         )
